/* //////////////////////////////////////////////////////////////////////// */
/* // emutil.c //////////////////////////////////////////////////////////// */
/* //////////////////////////////////////////////////////////////////////// */

//
// Event Monitor Project
// version 0.6
//
// Juan Manuel Casillas
// assman@gsyc.inf.uc3m.es
//
//
// 
// emlib [ Aka Event Monitor Library ]
//
// this library provides you an API for send messages to the
// server from inside programs written in C.
// 
// 
// This program is part of Event Monitor project (EM), 
// a system to manage and operate a heterogeneous 
// network, based on message-passing.
// See License file for details


#include "emutil.h"

/* //////////////////////////////////////////////////////////////////////// */
/* // error() ///////////////////////////////////////////////////////////// */
/* //////////////////////////////////////////////////////////////////////// */

void error(char num, char *cad) {
  switch (num) {
  case 0: printf("Can't create socket \n.");break;
  case 1: printf("Unable to connect with host %s \n",cad);break;
  case 2: printf("Can't manage this connection \n");break;
  case 3: printf("Can't extract info from buffer \n");break;
  case 4: printf("Can't Send info to server %s \n",cad);break;
  case 5: printf("Can't Receive info from server %s \n",cad);break;
  case 6: printf("Can't Connect to specified socket \n");break;
  case 7: printf("Can't install local client \n");break;
  case 8: printf("Config file %s is corrupt. Bailing out \n",cad);break;
  case 9:  printf("Can't open %s \n",cad); break;
  case 10: printf("Level must be between 0 and 9\n");break;
  }
exit(-1);
}

/* //////////////////////////////////////////////////////////////////////// */
/* // crear_socket() ////////////////////////////////////////////////////// */
/* //////////////////////////////////////////////////////////////////////// */

int new_socket(int dominio, int tipo,int port, char *ip_address, char bindit){
  int sfd;
  struct sockaddr_in serv_address;

  if ((sfd=socket(dominio,tipo,0))==-1) error(0,NULL);

  bzero((char *)&serv_address,sizeof(struct sockaddr_in));

  serv_address.sin_family=dominio;
  serv_address.sin_port=ntohs(port);
  serv_address.sin_addr.s_addr=*(long *)ip_address;

  if (bindit==1){
    if (bind(sfd,(struct sockaddr *)&serv_address,sizeof(serv_address))==-1)
	   error(0,NULL);
  }
  return sfd;
}


/* //////////////////////////////////////////////////////////////////////// */
/* // clear_string() ////////////////////////////////////////////////////// */
/* //////////////////////////////////////////////////////////////////////// */

void clear_string(char *cad) {
  int n;
	   
  for (n=0; n<strlen(cad); n++) {    
    if (cad[n]=='\n') cad[n]='\0';
    if (cad[n]=='\t') cad[n]=' ';
  }
  for (n=0; n<strlen(cad); n++) if (cad[n]=='\n') cad[n]='\0';
}

/* //////////////////////////////////////////////////////////////////////// */
/* // is_num() //////////////////////////////////////////////////////////// */
/* //////////////////////////////////////////////////////////////////////// */

int is_num(char *cad) {
int i;

 for (i=0; i<strlen(cad); i++) {
   if (!isdigit(cad[i])) return 0;
 }
  
 return 1;
} 
/* //////////////////////////////////////////////////////////////////////// */
/* // strip_comment() ///////////////////////////////////////////////////// */
/* //////////////////////////////////////////////////////////////////////// */
 
int strip_comment(char *str) {
char *p;

 if (str==NULL) {
   return -1;
 }

 p=strstr(str,CMARK);              
 if (p==NULL) {                       
   return 0;
 }

 while (*p!='\0') {
   *p='\0';
   p++;
 }
 
return 1;

}

/* //////////////////////////////////////////////////////////////////////// */
/* // prepare_string() //////////////////////////////////////////////////// */
/* //////////////////////////////////////////////////////////////////////// */

void prepare_string(char *cad) {
  if (cad==NULL) return;
  clear_string(cad);
  if (cad==NULL) return;
  strip_comment(cad);
}

/* //////////////////////////////////////////////////////////////////////// */
/* // read_cad() ////////////////////////////////////////////////////////// */
/* //////////////////////////////////////////////////////////////////////// */

void read_cad(FILE *f, char *cad) {
  bzero(cad,MAX_CAD);
  
  while (strlen(cad)==0) {
  if (fgets(cad,MAX_CAD,f)==NULL) {

    bzero(cad,MAX_CAD);
    return;
  }
  prepare_string(cad);
  }
}


/* //////////////////////////////////////////////////////////////////////// */
/* // Send_data() ///////////////////////////////////////////////////////// */
/* //////////////////////////////////////////////////////////////////////// */

int send_data(char *buffer, char *hname, 
	      char *S_ERVER, int P_ORT) {
int socketfd;
int n=0;
struct hostent *host, *srv;
struct sockaddr_in srv_address;

  if ((host=gethostbyname("127.0.0.1"))==NULL) error(7,hname);
  socketfd=new_socket(AF_INET,SOCK_STREAM,P_ORT,host->h_addr,0);

  if ((srv=gethostbyname(S_ERVER))==NULL) error(1,hname); 

  srv_address.sin_family=AF_INET;
  srv_address.sin_port=ntohs(P_ORT);
  srv_address.sin_addr.s_addr=*(long *)srv->h_addr;

  if (connect(socketfd,
	      (struct sockaddr *)&srv_address,sizeof(srv_address))==-1) {
    return -1;
  }

  n=sendto(socketfd,buffer,strlen(buffer),0,
		(struct sockaddr *)&srv_address,sizeof(srv_address));

  close(socketfd);
 return n;
}

/* //////////////////////////////////////////////////////////////////////// */
/* // parse_address() ///////////////////////////////////////////////////// */
/* //////////////////////////////////////////////////////////////////////// */

void parse_address(struct sockaddr_in addr, char *cad) {
unsigned char dir[4];
bzero(cad,ADDR_LEN);     
bcopy(&addr.sin_addr.s_addr,dir,sizeof(addr.sin_addr.s_addr));
sprintf(cad,"%d.%d.%d.%d",dir[0],dir[1],dir[2],dir[3]);
}

/* //////////////////////////////////////////////////////////////////////// */
/* // s2upper() /////////////////////////////////////////////////////////// */
/* //////////////////////////////////////////////////////////////////////// */

void s2upper(char *cad) {
int i;
     for (i=0; i<strlen(cad); i++) cad[i]=toupper(cad[i]);
}

	 
